@@ -77,6 +77,7 @@ typedef struct {
 	void     (*got_headers)         (SoupMessage *msg);
 	void     (*got_chunk)           (SoupMessage *msg);
 	void     (*got_body)            (SoupMessage *msg);
+	void     (*restarted)           (SoupMessage *msg);
 	void     (*finished)            (SoupMessage *msg);
 } SoupMessageClass;
 
@@ -101,8 +102,6 @@ void           soup_message_set_response        (SoupMessage       *msg,
 						 char              *resp_body,
 						 gulong             resp_length);
 
-void           soup_message_cancel              (SoupMessage       *msg);
-
 void           soup_message_add_header          (GHashTable        *hash,
 						 const char        *name,
 						 const char        *value);
@@ -188,7 +187,8 @@ guint          soup_message_get_flags           (SoupMessage        *msg);
  * Handler Registration 
  */
 typedef enum {
-	SOUP_HANDLER_PRE_BODY = 1,
+	SOUP_HANDLER_POST_REQUEST = 1,
+	SOUP_HANDLER_PRE_BODY,
 	SOUP_HANDLER_BODY_CHUNK,
 	SOUP_HANDLER_POST_BODY
 } SoupHandlerPhase;
@@ -250,7 +250,7 @@ void           soup_message_send_request        (SoupMessage       *req,
 						 gboolean           via_proxy);
 void           soup_message_read_request        (SoupMessage       *req,
 						 SoupSocket        *sock);
-void           soup_message_io_cancel           (SoupMessage       *msg);;
+void           soup_message_io_stop             (SoupMessage       *msg);
 void           soup_message_io_pause            (SoupMessage       *msg);
 void           soup_message_io_unpause          (SoupMessage       *msg);
 
@@ -263,6 +263,7 @@ void soup_message_got_informational   (SoupMessage *msg);
 void soup_message_got_headers         (SoupMessage *msg);
 void soup_message_got_chunk           (SoupMessage *msg);
 void soup_message_got_body            (SoupMessage *msg);
+void soup_message_restarted           (SoupMessage *msg);
 void soup_message_finished            (SoupMessage *msg);
 
 #endif /*SOUP_MESSAGE_H*/
